@@ -16,7 +16,7 @@ Usage::
     session_client: ImagebuilderClient = session.client("imagebuilder")
     ```
 """
-from mypy_boto3_imagebuilder.client import ImagebuilderClient, ImagebuilderClient as Client
+from mypy_boto3_imagebuilder.client import ImagebuilderClient as Client, ImagebuilderClient
 
 
 __all__ = ("Client", "ImagebuilderClient")
